pub struct PermanentRoot(Heap<JSVal>);Expand description
A manual GC root that will exist until this PermanentRoot is dropped. Maintains a GC root for the contained value until this object is dropped.
Safety
The root (and the contained value) is only valid as long as this value is never moved after it is initialized. It should only be used inside of a container like Box or Rc and never extracted from it.
Tuple Fields
0: Heap<JSVal>Implementations
Sourceimpl PermanentRoot
impl PermanentRoot
Sourcepub unsafe fn init(
&self,
cx: &JSContext,
object: *mut JSObject,
name: &'static CStr,
)
pub unsafe fn init( &self, cx: &JSContext, object: *mut JSObject, name: &'static CStr, )
Add a GC root for the provided JS object.
Safety
- This method must only be called on a
PermanentRootthat will not move for the remainder of its lifetime (e.g. inside of Box, Rc, etc.) - This must only be called once per instance of
PermanentRoot